Module decoder

Module decoder 

Structs

CodecParameters
Parameters needed to open a decoder, extracted from stream info.
DecoderBuilder
Builder for creating decoders. Follows the builder pattern instead of FFmpeg’s allocate-then-mutate.
DecoderDescriptor
Descriptor for a decoder implementation, used in the registry.

Traits

Decoder
Decoder trait — the main abstraction for all decoders.