pub struct DecoderDescriptor {
pub codec_id: CodecId,
pub name: &'static str,
pub long_name: &'static str,
pub media_type: MediaType,
pub capabilities: CodecCapabilities,
pub properties: CodecProperties,
pub priority: i32,
}Expand description
Descriptor for a decoder implementation, used in the registry.
Fields
codec_id: CodecIdname: &'static strlong_name: &'static strmedia_type: MediaTypecapabilities: CodecCapabilitiesproperties: CodecPropertiespriority: i32Priority for registry selection. Higher priority wins when multiple decoders support the same codec_id. Native implementations use 100, wrapper/adapter implementations use 50.