pub struct EncoderDescriptor {
pub codec_id: CodecId,
pub name: &'static str,
pub long_name: &'static str,
pub media_type: MediaType,
pub capabilities: CodecCapabilities,
pub properties: CodecProperties,
pub supported_sample_formats: &'static [SampleFormat],
pub supported_pixel_formats: &'static [PixelFormat],
pub priority: i32,
}Expand description
Descriptor for an encoder implementation, used in the registry.
Fields
codec_id: CodecIdname: &'static strlong_name: &'static strmedia_type: MediaTypecapabilities: CodecCapabilitiesproperties: CodecPropertiessupported_sample_formats: &'static [SampleFormat]supported_pixel_formats: &'static [PixelFormat]priority: i32Priority for registry selection. Higher priority wins when multiple encoders support the same codec_id. Native implementations use 100, wrapper/adapter implementations use 50.